@@ -148,6 +148,16 @@ class SQLiteHandler(object):
         sqlrecords = self.database.read_records(tablename=tablename, columns=table.column_names)
         table.records = self.transform_sql_to_record(column_names=table.column_names, sqlrecords=sqlrecords)
 
+    def table_create_add_records(self, tablename, recordsvalues):
+        """
+        create records from given values and immediately add records in one go to specified table
+        """
+
+        records = self.records_create(tablename, recordsvalues)
+        self.table_add_records(tablename, records)
+
+        return records
+
     def table_add_records(self, tablename, records):
 
         table = self.database.tables[tablename]
@@ -258,7 +268,7 @@ class SQLiteHandler(object):
         foreign_table = self.table_get_foreign_table(tablename=tablename, column=column)
         
         # get the records from the foreign table
-        records = self.table_read_records(foreign_table)
+        records = self.table_read_records(foreign_table.name)
         # print(f"record objects of foreign table {records}")
 
         # get the foreign keys to filter on
@@ -310,7 +320,6 @@ class SQLiteHandler(object):
 
         for key in self.database.tables:
             if ("CROSSREF" in key) and (tablename in key):
-                crossrefname = key
                 key = key.replace("CROSSREF", '')
                 key = key.replace(tablename, '')
                 key = key.replace('_', '')
@@ -355,9 +364,6 @@ class SQLiteHandler(object):
         3 - 8
         """
 
-        table1 = self.database.tables[tablename1]
-        table2 = self.database.tables[tablename2]
-
         # get the cross reference table
         crossref = self.crossref_get_one(
             tablename1 = tablename1,
@@ -450,7 +456,7 @@ class SQLiteHandler(object):
 
         return records
 
-    def record_create(self, tablename, values=[]):
+    def record_create(self, tablename, values=[], recordarray=[]):
         """
         creates a draft record that can still be 
         manipulated before making it definitive
@@ -462,11 +468,19 @@ class SQLiteHandler(object):
 
         table = self.database.tables[tablename]
 
-        if values == []:
-            recordarray = table.defaults
-        else:
+        # if recordarray is given, take it as is
+        if recordarray != []:
+            pass
+
+        # if instead only values is given, add a new id in front and take that as recordarray
+        # (this will be a new record in the database and has therefore no id yet)
+        elif values != []:
             recordarray = [-1] + values
 
+        # if nothing is given, fill the values with default values
+        else:
+            recordarray = table.defaults
+
         record = Record(
             table.column_names,
             recordarray,
@@ -524,257 +538,4 @@ class SQLiteHandler(object):
             where = [["id", where]]
 
         # otherwise, no transform is needed
-        return where
-
-
-def print_records(records):
-    for record in records:
-        print(f"primarykey: {record.primarykey}, recordpairs: {record.recordpairs}")
-
-
-if __name__ == "__main__":
-
-    # opening a database
-    handler = SQLiteHandler()
-    handler.database_open(filename="science")
-    handler.database_delete()
-    handler.database_new(filename="science")
-
-    # adding a table
-    table_scientists = handler.table_create(
-        tablename="scientists",
-        column_names = ["age", "gender_id"],
-        column_types = ["Integer", "INTEGER REFERENCES genders(id)"],
-    )
-    print(f"Database contains {handler.database.tables}")
-
-    # adding multiple records
-    records = []
-    records += [handler.record_create(
-        tablename="scientists",
-        values=[1, "Hawking", 68, 2],
-        )]
-    records += [handler.record_create(
-        tablename="scientists",
-        values=[2, "Marie Curie", 20, 2],
-        )]
-    records = handler.table_add_records(tablename="scientists", records=records)
-    print(f"creating multiple records")
-    print_records(records)
-    
-    # adding single records
-    records = []
-    records += [handler.record_create(
-        tablename="scientists",
-        values=[3, "Einstein", 100, 1],
-        )]
-    records = handler.table_add_records(tablename="scientists", records=records)
-    print(f"creating single records")
-    print_records(records)
-
-    # adding multiple records
-    records = []
-    records += [handler.record_create(
-        tablename="scientists",
-        values=[4, "Rosenburg", 78, 1],
-        )]
-    records += [handler.record_create(
-        tablename="scientists",
-        values=[5, "Neil dGrasse Tyson", 57, True],
-        )]
-    records = handler.table_add_records(tablename="scientists", records=records)
-    print(f"creating multiple records")
-    print_records(records)
-
-    # conditional read with where statement
-    where = [["gender_id", [1]]]
-    records = handler.table_read_records(tablename="scientists", where=where)
-    print(f"read where")
-    print_records(records)
-
-    # update with where statement
-    valuepairs = [["gender_id", 1]]
-    where = [["name", ["Hawking"]]]
-    records = handler.table_update_records(tablename="scientists", valuepairs=valuepairs, where=where)
-    print(f"update true to false")
-    print_records(records)
-
-    # update with direct primary id
-    valuepairs = [["name", "Neil de'Grasse Tyson"], ["age", 40]]
-    rowid = 5
-    records = handler.table_update_records(tablename="scientists", valuepairs=valuepairs, where=rowid)
-    print(f"update record 'id = 5'")
-    print_records(records)
-
-    # get records without table object, but with tablename
-    records = handler.table_read_records(tablename="scientists")
-    print(f"read all records")
-    print_records(records)
-
-    # adding a table
-    table_nobel = handler.table_create(
-        tablename = "nobelprizes",
-        column_names=["description"],
-        column_types=["TEXT"],
-    )
-    table_papers = handler.table_create(
-        tablename = "papers",
-        column_names=["description"],
-        column_types=["TEXT"],
-    )
-    table_nobel = handler.table_create(
-        tablename = "ignorants",
-        column_names=["description"],
-        column_types=["TEXT"],
-    )
-
-    # adding multiple records in one go
-    records = handler.records_create(
-        tablename="nobelprizes",
-        recordsvalues=[
-            [1, "Peace", "Peace nobel prize"],
-            [2, "Economy", "Economy nobel prize"],
-            [3, "Physics", "Physics nobel prize"],
-            [4, "Sociology", "Sociology nobel prize"],
-            ]
-        )
-    records = handler.table_add_records(tablename="nobelprizes", records=records)
-    print(f"creating multiple records")
-    print_records(records)
-
-    # adding multiple records in one go
-    records = handler.records_create(
-        tablename="papers",
-        recordsvalues=[
-            [1, "Palestine", "Extrapolation on the palestinian cause"],
-            [2, "Wealth", "On the Wealth of Nations"],
-            [3, "Time", "A brief history of time"],
-            [4, "Fear", "Controlling your fear"],
-            ]
-        )
-    records = handler.table_add_records(tablename="papers", records=records)
-    print(f"creating multiple records")
-    print_records(records)
-
-    # adding a crossref table
-    crossref_table = handler.crossref_create(
-        tablename1="scientists",
-        tablename2="nobelprizes",
-    )
-    print(f"Database contains {handler.database.tables}")
-
-    # adding a crossref table
-    crossref_table = handler.crossref_create(
-        tablename1="scientists",
-        tablename2="papers",
-    )
-    print(f"Database contains {handler.database.tables}")
-
-    # get crossreferences
-    crossreferences = handler.crossref_get_all(tablename="scientists")
-    print(f"Table scientists has links to:")
-    for crossreference in crossreferences:
-        print(f"- {crossreference.name}")
-
-    # adding a crossref
-    handler.crossref_add_record(
-        tablename1="scientists",
-        tablename2="nobelprizes",
-        where1=[
-            ["name", ["Hawking"]]
-            ],
-        where2=[
-            ["name", ["Economy"]]
-            ],
-    )
-
-    # adding a crossref
-    handler.crossref_add_record(
-        tablename1="scientists",
-        tablename2="nobelprizes",
-        where1=[
-            ["name", ["Einstein"]]
-            ],
-        where2=[
-            ["name", ["Physics", "Peace"]]
-            ],
-        description="Einstein wins both peace and physics nobel prizes"
-    )
-
-    # adding crossreff based upon primary keys
-    handler.crossref_add_record(
-        tablename1="scientists",
-        tablename2="papers",
-        where1=[1],
-        where2=[3, 4],
-        description="Hawking wrote papers about time and fear of time"
-    )
-
-    # reading crossreferences of all scientists and nobelprizes
-    records = handler.crossref_read_records(
-        tablename1="scientists",
-        tablename2="nobelprizes",
-        )
-    print_records(records)
-
-    # reading crossreferences of a single scientist and papers
-    records = handler.crossref_read_record(
-        tablename1="scientists",
-        tablename2="papers",
-        rowid=1,
-    )
-    print(f"looking up Hawkings papers:")
-    print_records(records)
-
-    where = [
-        ["name", ["Rosenburg"]]
-    ]
-    handler.table_delete_records(tablename="scientists", where=where)
-    print(f"deleted record rosenburg")
-    records = handler.table_read_records(tablename="scientists")
-    print_records(records)
-
-    handler.table_delete(tablename="ignorants")
-
-    # gathering all records of all tables
-    recordset = []
-    for tablename in handler.database.tables:
-        records = handler.table_read_records(tablename)
-        recordset += [records]
-    
-    # printing all the records of all tables
-    print(f"Database contains {handler.database.tables}")
-    for records in recordset:
-        print("")
-        print_records(records)
-  
-
-
-
-    # records = reltbl.readForeignValues('charid1')
-
-    # db.saveas_database(filename="backup")
-    # db.close_database()
-
-    # filename = "science"
-
-    # db = Database(filename=filename)
-
-    # teachertbl = db.create_table(
-    #     name="teachers",
-    #     column_names = ["ordering", "name", "age", "active"],
-    #     column_types = ["INTEGER", "Text", "Integer", "Bool"],
-    # )
-
-    # db.delete_table(teachertbl)
-
-    # table_scientists = db.get_table("scientists")
-
-    # where = [["nobelprizewinner", [True]]]
-    # records = table_scientists.readRecords(where=where)
-
-    # table_scientists.deleteRecords(records)
-
-    # for table in db.tables:
-    #     print(f"printing for table: {table.name}")
-    #     print_records(table.records)
\ No newline at end of file
+        return where
\ No newline at end of file
